@@ -37,6 +37,12 @@ model <- mxModel(name="count",
 model <- mxRun(model, silent=TRUE)
 omxCheckTrue(counter > 1)
 
+###
+
+omxCheckError(mxCheckIdentification(model), "Identification check is not possible for models with 'MxFitFunctionAlgebra', 'MxFitFunctionRow', and 'MxFitFunctionR' fit functions.
+ If you have a multigroup model, use mxFitFunctionMultigroup.")
+
+
 ###
 
 toomany <- function(marg,state) {
