@@ -99,7 +99,7 @@ void omxComputeGD::initFromFrontend(omxState *globalState, SEXP rObj)
 #if HAS_NPSOL
 		engine = OptEngine_NPSOL;
 #else
-		Rf_error("NPSOL is not available in this build");
+		Rf_error("NPSOL is not available in this build. See ?omxGetNPSOL() to download this optimizer");
 #endif
 	} else if(strEQ(engineName, "SD")){
 		engine = OptEngine_SD;
@@ -513,7 +513,7 @@ void ComputeCI::computeImpl(FitContext *mle)
 
 			double dist = lower? currentCI->lbound : currentCI->ubound;
 			bool better = (fc.inform != INFORM_STARTING_VALUES_INFEASIBLE &&
-				       fabs(fc.fit - fc.targetFit) < (dist * .05) &&
+				       ((!useInequality && !useEquality) || fabs(fc.fit - fc.targetFit) < (dist * .05)) &&
 				       ((!std::isfinite(*store) ||
 					 (lower && val < *store) || (!lower && val > *store))));
 
