@@ -47,6 +47,19 @@ typedef struct omxThresholdColumn omxThresholdColumn;
 #include "omxFitFunction.h"
 #include "omxState.h"
 
+struct omxDefinitionVar {		 	// Definition Var
+
+	int column;		// Where it comes from
+	int numLocations;		// Num locations
+	int* rows;				// row positions
+	int* cols;				// column positions
+	int* matrices;			// matrix numbers
+	int  numDeps;           // number of algebra/matrix dependencies
+	int* deps;              // indices of algebra/matrix dependencies
+
+	void loadData(omxState *state, double val);
+};
+
 struct omxContiguousData {
 	int isContiguous;
 	int start;
@@ -95,11 +108,17 @@ class omxData {
 	int* identicalDefs;					// Number of consecutive rows with identical def. vars
 	int* identicalMissingness;			// Number of consecutive rows with identical missingness patterns
 	int* identicalRows;					// Number of consecutive rows with identical data
+
+	std::vector<omxDefinitionVar> defVars;
  public:
 	int rows, cols;						// Matrix size 
 	int verbose;
 	omxState *currentState;
 
+	void loadFakeData(double fake);
+	int handleDefinitionVarList(omxState *state, int row, double* oldDefs);
+	bool hasDefinitionVariables() { return defVars.size() != 0; };
+
 	// Used when the expectation provides the observed data (DataDynamic)
 	std::vector<struct omxExpectation *> expectation;   // weak pointers
 	int version;
@@ -165,4 +184,7 @@ void omxPrintData(omxData *od, const char *header);
 
 double omxDataDF(omxData *od);
 
+SEXP findIdenticalRowsData(SEXP data, SEXP missing, SEXP defvars,
+			   SEXP skipMissingness, SEXP skipDefvars);
+
 #endif /* _OMXDATA_H_ */
